package com.ruoyi.web.controller.ems;

import com.huashe.common.domain.AjaxResult;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.ems.domain.MeterDevice;
import com.ruoyi.ems.model.QueryDevice;
import com.ruoyi.ems.service.IMeterDeviceService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 计量设备Controller
 *
 * @author ruoyi
 * @date 2024-08-08
 */
@RestController
@RequestMapping("/ems/meterDevice")
@Api(value = "MeterDeviceController", description = "计量设备管理")
public class MeterDeviceController extends BaseController {
    @Autowired
    private IMeterDeviceService meterDeviceService;

    /**
     * 查询计量设备列表
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:list')")
    @GetMapping("/list")
    public TableDataInfo list(QueryDevice queryDevice) {
        startPage();
        List<MeterDevice> list = meterDeviceService.selectMeterDeviceList(queryDevice);
        return getDataTable(list);
    }

    /**
     * 导出计量设备列表
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:export')")
    @Log(title = "计量设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, QueryDevice queryDevice) {
        List<MeterDevice> list = meterDeviceService.selectMeterDeviceList(queryDevice);
        ExcelUtil<MeterDevice> util = new ExcelUtil<MeterDevice>(MeterDevice.class);
        util.exportExcel(response, list, "计量设备数据");
    }

    /**
     * 获取计量设备详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(meterDeviceService.selectMeterDeviceById(id));
    }

    /**
     * 新增计量设备
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:add')")
    @Log(title = "计量设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MeterDevice meterDevice) {
        return toAjax(meterDeviceService.insertMeterDevice(meterDevice));
    }

    /**
     * 修改计量设备
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:edit')")
    @Log(title = "计量设备", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MeterDevice meterDevice) {
        return toAjax(meterDeviceService.updateMeterDevice(meterDevice));
    }

    /**
     * 删除计量设备
     */
    @PreAuthorize("@ss.hasPermi('ems:meterdevc:remove')")
    @Log(title = "计量设备", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(meterDeviceService.deleteMeterDeviceByIds(ids));
    }
}
